# pagr - the Python Aggregator

## Development
### Upload to pip
1. Make sure that the version number has been updated
1. Generate dist files `python setup.py sdist bdist_wheel`
1. Upload to PyPI `twine upload dist/*`
